#!/bin/sh

vchans=`sysctl -n hw.snd.pcm0.vchans`
if [ $vchans -ne 0 ] ; then
    echo "This test needs to be run without vchans enabled and preferably on"
    echo "hardware that supports 8, 44.1, and 48kHz sampling."
    exit 1
fi

# ignore dd output
exec 2>/dev/null

echo "Demo 1a: Upsampling modulated 212Hz tone"

echo "  44.1kHz sample rate (no conversion)"
./tonegen -c 2 -s conv 212 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2

echo "  8kHz sample rate upsampled to 44.1kHz (current converter)"
./tonegen -c 2 -s conv 212 8000 | ./feeder_rate_fbsd -c 2 8000 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2

echo "  8kHz sample rate upsampled to 44.1kHz (proposed converter)"
./tonegen -c 2 -s conv 212 8000 | ./feeder_rate_new -c 2 8000 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2


sleep 5


echo "Demo 1b: Upsampling modulated 212Hz tone"

echo "  48kHz sample rate (no conversion)"
./tonegen -c 2 -s conv 212 48000 | \
    dd count=300 | ./rawplay -c 2 48000
sleep 2

echo "  8kHz sample rate upsampled to 48kHz (current converter)"
./tonegen -c 2 -s conv 212 8000 | ./feeder_rate_fbsd -c 2 8000 48000 | \
    dd count=300 | ./rawplay -c 2 48000
sleep 2

echo "  8kHz sample rate upsampled to 48kHz (proposed converter)"
./tonegen -c 2 -s conv 212 8000 | ./feeder_rate_new -c 2 8000 48000 | \
    dd count=300 | ./rawplay -c 2 48000
sleep 2



sleep 5



echo "Demo 2a: Downsampling modulated 212Hz tone"
echo "  44.1kHz sample rate (no conversion)"
./tonegen -c 2 -s conv 212 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2

echo "  48kHz sample rate downsampled to 44.1kHz (current converter)"
./tonegen -c 2 -s conv 212 48000 | ./feeder_rate_fbsd -c 2 48000 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2

echo "  48kHz sample rate downsampled to 44.1kHz (proposed converter)"
./tonegen -c 2 -s conv 212 48000 | ./feeder_rate_new -c 2 48000 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2



sleep 5



echo "Demo 2b: Downsampling modulated 212Hz tone"
echo "  44.1kHz sample rate (no conversion)"
./tonegen -c 2 -s conv 212 44100 | \
    dd count=300 | ./rawplay -c 2 44100
sleep 2

echo "  44.1kHz sample rate downsampled to 8kHz (current converter)"
./tonegen -c 2 -s conv 212 44100 | dd count=300 | \
    ./feeder_rate_fbsd -c 2 44100 8000 | ./rawplay -c 2 8000
sleep 2

echo "  44.1kHz sample rate downsampled to 8kHz (proposed converter)"
./tonegen -c 2 -s conv 212 44100 | dd count=300 | \
    ./feeder_rate_new -c 2 44100 8000 | ./rawplay -c 2 8000
sleep 2

