/*
 * Copyright (c) 2003 Orion Hodson <oho@acm.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <errno.h>
#include <inttypes.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

struct pcm_feeder {
	void *data;
	void *source;
};

static int slurp(uint8_t* buf, uint32_t buf_bytes);

struct pcm_channel;

#define DSP_DEFAULT_SPEED 8000

#define FEEDRATE_SRC 1
#define FEEDRATE_DST 2

#define UNUSED(x) (x) = (x)

#define FEEDER_FEED(src, chan, buf, buf_bytes, src2)  			      \
	   slurp(buf, buf_bytes); UNUSED(src); UNUSED(chan); UNUSED(src2)

#define M_RATEFEEDER 0
#define M_WAITOK     0
#define M_ZERO       0

#define malloc(x, y, z) calloc(x, 1)
#define free(x, y) free(x)

#define RATE_ASSERT(x, y...) 						      \
	do {								      \
    	if (!(x)) {							      \
	    printf y;							      \
	    abort();							      \
	    }								      \
	} while (0)

#ifndef min
#define min(a,b) (((a) < (b)) ? (a) : (b))
#endif /* min */

#ifdef RATE_DEBUG
#define RATE_TRACE(x...)  fprintf(stderr, x) 
#else
#define RATE_TRACE(x...)
#endif

