#include <assert.h>
#include <inttypes.h>
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <sysexits.h>
#include <unistd.h>

#define IN_SAMPLES 64

static void
usage(void)
{
        fprintf(stderr, "timeline [ -c <channels> ] <smpl_rate>");
        exit(EX_USAGE);
}

static void
timeline(uint16_t srate, uint16_t channels)
{
	int16_t sbuf[IN_SAMPLES];
	
	uint32_t t = 0;
	uint16_t i, c;
	size_t got;

	while ((got = fread(sbuf, channels * sizeof(sbuf[0]), 
			    IN_SAMPLES / channels, stdin)) > 0) {
		for (i = 0; i < got; i ++) {
			printf("%8.8f ", (double)t / (double)srate);
			for (c = 0; c < channels; c++) {
				printf("% 5d ", sbuf[c + channels * i]);
			}
			printf("\n");
			fflush(stdout);
			t++;
		}
	}
}

int main(int argc, char * const * argv)
{
	int channels, srate, ch;

	channels = 1;

	while ((ch = getopt(argc, argv, "c:")) != -1) {
                switch (ch) {
                case 'c':
                        channels = atoi(optarg);
                        break;
                case '?':
                default:
                        usage();
                }
	}

	argc -= optind;
	argv += optind;

	if (argc != 1)
                usage();

        srate = atoi(argv[0]);
	if (srate == 0 || srate > 48000) {
                fprintf(stderr, "smpl_rate must be in range 1--48000");
                usage();
        }

	timeline(srate, channels);

	return 0;
}
